@@ -21,18 +21,13 @@
 
 #include <kauthhelpersupport.h>
 
+#include <QCoreApplication>
 #include <QDebug>
 
-#include <unistd.h>
-
-#if defined(Q_CC_MSVC)
-// TODO: or rather use uid_t in the getuid() call below?
-#define __uid_t uid_t
-#endif
-
-ActionReply SaveHelper::save(QVariantMap args)
+ActionReply SaveHelper::save(const QVariantMap &args)
 {
-    __uid_t uid = getuid();
+    Q_UNUSED(args);
+    const quint64 uid = QCoreApplication::applicationPid();
     qDebug() << "executing uid=" << uid;
 
     return ActionReply::SuccessReply();
